@@ -81,7 +81,6 @@ class MountedVolumeSerializer(serializers.ModelSerializer):
 
 
 class LinuxDeviceSerializer(serializers.ModelSerializer):
-    mounted_volume = NestedMountedVolumeSerializer(required=False, allow_null=True)
 
     class Meta:
         model = LinuxDevice
@@ -89,7 +88,7 @@ class LinuxDeviceSerializer(serializers.ModelSerializer):
             "id",
             "device",
             "type",
-            "mounted_volume",
+            "size",
             "created",
             "last_updated",
             "custom_fields",
