@@ -126,11 +126,11 @@ class LVMTemplateForm(NetBoxModelForm):
         #print(f"Physical Volume ID: {pv.id}")
 
         # Add linux_device for lvm
-        pv_type_pk = ContentType.objects.get(app_label='netbox_storage', model='physicalvolume').pk
+        pv_type_pk = ContentType.objects.get(app_label='netbox_storage', model='volumegroup').pk
         linux_device_mapper = LinuxDevice.objects.create(device='/dev/mapper/vg_system-lv_home',
                                                          type='LVM',
                                                          size=pv_linux_device.size,
-                                                         object_id=pv.pk,
+                                                         object_id=volume_group.pk,
                                                          content_type_id=pv_type_pk)
         #print(f"Linux Device ID: {linux_device_mapper.id}")
 
