@@ -69,14 +69,14 @@ class TemplateVolumeConfig(PluginTemplateExtension):
                                           type='Partition').count() == 0:
                 print(f"Right Page Lonely Drive: {drive}")
                 lonely_drives.append(drive)
-                partition_dict[str(drive.identifier)] = None
+                partition_dict[drive] = None
             else:
                 drives_with_partition.append(drive)
                 partitions.append(list(LinuxDevice.objects.filter(content_type_id=linux_device_type_id,
                                                                   object_id=linux_device_drive.pk, type='Partition')))
-                partition_dict[str(drive.identifier)] = LinuxDevice.objects.filter(content_type_id=linux_device_type_id,
+                partition_dict[drive] = list(LinuxDevice.objects.filter(content_type_id=linux_device_type_id,
                                                                                    object_id=linux_device_drive.pk,
-                                                                                   type='Partition')
+                                                                                   type='Partition'))
 
         amount_partitions = len(partitions)
         print(f"R Lonely Drives: {lonely_drives}")
